Běžná tlačítka

Běžná tlačítka | Obsah

Níže je krátce popsáno každé tlačítko.

| Zkopíruje aktuálně vybraný obsah do schránky. (Ctrl+C)
| Vyjme aktuálně vybraný obsah do schránky. (Ctrl+X)
| Vloží obsah schránky do okna editoru. (Ctrl+P)
| Ztuční text.
| Naformátuje text kurzívou.
| Podtrhne text.
| Přeškrtne text.
| Zarovná vlevo.
| Zarovná na střed.
| Zarovná vpravo.
| Zarovná do bloku.
| Neřazený seznam/seznam s odrážky.
| Řazený seznam/číslovaný seznam.
| Předsadí/sníží odsazení.
| Odsadí/zvýší odsazení.
| Vrátí zpět naposledy provedenou akci.
| Obnoví poslední akci.
| Vloží nový odkaz, více o této funkci v části Vložit odkaz.
| Zruší odkaz v aktuálním výběru/odstranit všechny vybrané odkazy.
| Vloží nový obrázek, více o této funkci v části Vložit obrázek.
| Vyčistí kód/odstraní nechtěné formátování. Tato funkce se hodí když kopírujete obsah například z kancelářského balíku.
| Zobrazí tuto nápovědu.
| Otevře editor s HTML zdrojem.
| Do aktuální pozice vloží novou 2x2 tabulku.
| Přidá řádek před aktuální.
| Přidá řádek pod aktuální.
| Odstraní řádek.
| Přidá sloupec před aktuální.
| Přidá sloupec za aktuální.
| Odstraní aktuální sloupec.
| Přidá nový vodorovný oddělovač.
| Odstraní z výběru formátování.
| Vytvoří z vybraného textu dolní index.
| Vytvoří z vybraného textu horní index.

Jdi na: Obsah | Nahoru